#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  text2qrcode.py
#  
#  Copyright 2015 Philippe Bonnet <phil.bonnet@laposte.net>
#  
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#  
#  19/06/15 Phil_B  : Suppression des options cachée (Pb avec V4. inkscape)

# standard library
import os
import sys
import re

import inkex
import qrcode
import base64
from PIL import Image, ImageFilter

class QRCodeConvert(inkex.Effect):
    """
    Convertir les champs texte d'un calque en image QRCode
    """
    def __init__(self):
        inkex.Effect.__init__(self)
        self.OptionParser.add_option("", "--active-tab", action="store", type="string", dest="active_tab", default="",     help="Defines which tab is active")
        self.OptionParser.add_option("", "--text2code",  action="store", type="string", dest="text2code",  default="",     help="Chaine à coder")

    def effect(self):
        """
        Méthode principale
        """
        if self.options.active_tab == '"help"' :
            return
        if self.options.active_tab == '"QRCode"' :
            """ 
            try to find qrcode layer else create one
            """
            lqrc  = None
            for i in self.document.getroot():
                if i.tag == inkex.addNS('g','svg') and i.get(inkex.addNS('label','inkscape')) == 'qrcode':
                    lqrc = i
                    break
            if lqrc is None:
                lqrc = self.add_layer(self.document.getroot(),'qrcode')
            """
            Create QRCode with text from qrcode layer 
            else from text2code pamameter
            """
            string2convert = ""
            for t in lqrc:
                if t.tag == inkex.addNS('text','svg'):
                    for s in t:
                        if s.tag == inkex.addNS('tspan','svg'):
                            if s.text:
                                string2convert += s.text + '\r\n'
                    lqrc.remove(t)
            if string2convert == "": string2convert = self.options.text2code
            self.create_qrcode(lqrc, string2convert)
        return

    def create_qrcode(self, node, str2conv):
        fic = "/tmp/tmp_qrcode.png" # TODO : éviter le fichier /tmp
        qrcode.make(str2conv).save(fic)
        file = open(fic,"rb").read()
        type='image/png'
        inkex.etree.SubElement(node,inkex.addNS('image','svg'),{
                    inkex.addNS('height'):'25.0',
                    inkex.addNS('width'):'25.0',
                    inkex.addNS('x'):'0.0',
                    inkex.addNS('y'):'0.0',
                    inkex.addNS('href','xlink'):'data:%s;base64,%s' % (type, base64.encodestring(file))})
    
    def add_layer(self, node, label):
        return inkex.etree.SubElement(node,inkex.addNS('g','svg'),{
                    inkex.addNS('label','inkscape'):label,
                    inkex.addNS('groupmode','inkscape'):'layer',
                    inkex.addNS('style'):'display:inline'})
        


def main():
    qrconv = QRCodeConvert()
    qrconv.affect()
    return 0

if __name__ == '__main__':
	main()
